@@ -14,6 +14,7 @@ import java.util.Vector;
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.AppBarEvent;
 import org.gnu.gnome.event.AppBarListener;
@@ -38,7 +39,7 @@ public class AppBar extends HBox {
 	/**
 	 * Construct an AppBar using a handle to a native resource.
 	 */
-	public AppBar(int handle) {
+	public AppBar(Handle handle) {
 		super(handle);
 	}
 
@@ -62,7 +63,7 @@ public class AppBar extends HBox {
 	 * @return The progress bar.
 	 */
 	public ProgressBar getProgressBar() {
-		int hndl = gnome_appbar_get_progress(getHandle());
+		Handle hndl = gnome_appbar_get_progress(getHandle());
 		GObject obj = retrieveGObject(hndl);
 		if (null != obj)
 			return (ProgressBar)obj;
@@ -227,24 +228,20 @@ public class AppBar extends HBox {
 		anEvtMap.addEvent("clear_prompt", "handleClearPrompt", AppBarEvent.Type.CLEAR_PROMPT, AppBarListener.class);
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_appbar_get_type();
-	native static final protected int gnome_appbar_new(boolean hasProgress, boolean hasStatus, int interactivity);
-	native static final protected void gnome_appbar_set_status(int appbar, String status);
-	native static final protected int gnome_appbar_get_status(int appbar);
-	native static final protected void gnome_appbar_set_default(int appbar, String defaultStatus);
-	native static final protected void gnome_appbar_push(int appbar, String status);
-	native static final protected void gnome_appbar_pop(int appbar);
-	native static final protected void gnome_appbar_clear_stack(int appbar);
-	native static final protected void gnome_appbar_set_progress_percentage(int appbar, double percentage);
-	native static final protected int gnome_appbar_get_progress(int appbar);
-	native static final protected void gnome_appbar_refresh(int appbar);
-	native static final protected void gnome_appbar_set_prompt(int appbar, String prompt, boolean modal);
-	native static final protected void gnome_appbar_clear_prompt(int appbar);
-	native static final protected String gnome_appbar_get_response(int appbar);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected Handle gnome_appbar_new(boolean hasProgress, boolean hasStatus, int interactivity);
+	native static final protected void gnome_appbar_set_status(Handle appbar, String status);
+	native static final protected Handle gnome_appbar_get_status(Handle appbar);
+	native static final protected void gnome_appbar_set_default(Handle appbar, String defaultStatus);
+	native static final protected void gnome_appbar_push(Handle appbar, String status);
+	native static final protected void gnome_appbar_pop(Handle appbar);
+	native static final protected void gnome_appbar_clear_stack(Handle appbar);
+	native static final protected void gnome_appbar_set_progress_percentage(Handle appbar, double percentage);
+	native static final protected Handle gnome_appbar_get_progress(Handle appbar);
+	native static final protected void gnome_appbar_refresh(Handle appbar);
+	native static final protected void gnome_appbar_set_prompt(Handle appbar, String prompt, boolean modal);
+	native static final protected void gnome_appbar_clear_prompt(Handle appbar);
+	native static final protected String gnome_appbar_get_response(Handle appbar);
+
 }
